# Aorta-Sirius

The Global Python SDK for the Central Finite Curve

[![codecov](https://codecov.io/gh/kontinuum-investments/Aorta-Sirius/branch/production/graph/badge.svg?token=TYY4X666XE)](https://codecov.io/gh/kontinuum-investments/Aorta-Sirius)

# Installation

## Required Environmental Variables

- `APPLICATION_NAME` _(Used as the default Discord Server Name)_
- `DISCORD_BOT_TOKEN`
- `SENTRY_URL`
- `WISE_PRIMARY_ACCOUNT_API_KEY`
- `WISE_SECONDARY_ACCOUNT_API_KEY`
- `MONGO_DB_CONNECTION_STRING`
- `ENTRA_ID_CLIENT_ID` - Entra ID Client ID
- `ENTRA_ID_TENANT_ID` - Entra ID Tenant ID
- `ENVIRONMENT` - Determines which environment it is currently in; either `Production`, `Test`, `Development` or `CI/CD Pipeline`

## CI/CD Pipeline
## Required Repository Secrets
- `CODECOV_TOKEN`
- `PYPI_ACCESS_TOKEN`
- `QODANA_TOKEN`
- `DISCORD_BOT_TOKEN`

## Required Organizational Variables
- `APPLICATION_NAME` _(Used as the default Discord Server Name)_
- `ENVIRONMENT` - Determines which environment it is currently in; either `Production`, `Test`, `Development` or `CI/CD Pipeline`

## Required Organizational Secrets
- `SENTRY_URL`
- `WISE_PRIMARY_ACCOUNT_API_KEY`
- `WISE_SECONDARY_ACCOUNT_API_KEY`